@@ -35,11 +35,11 @@
 #include <Akonadi/AttributeFactory>
 #include <Akonadi/CollectionIdentificationAttribute>
 
-#include <Akonadi/Calendar/CalendarClipboard>
-#include <Akonadi/Calendar/FreeBusyManager>
-#include <Akonadi/Calendar/IncidenceChanger>
-#include <Akonadi/Calendar/TodoPurger>
-#include <akonadi/calendar/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
+#include <Akonadi/CalendarClipboard>
+#include <Akonadi/FreeBusyManager>
+#include <Akonadi/IncidenceChanger>
+#include <Akonadi/TodoPurger>
+#include <akonadi/calendarsettings.h> //krazy:exclude=camelcase this is a generated file
 
 #include <Akonadi/CollectionMaintenancePage>
 #include <Akonadi/CollectionPropertiesDialog>
@@ -1971,7 +1971,7 @@ Akonadi::Item CalendarView::selectedTodo()
     if (const KCalendarCore::Todo::Ptr t = CalendarSupport::todo(item)) {
         return item;
     }
-    return Akonadi::Item();
+    return {};
 }
 
 void CalendarView::dialogClosing(const Akonadi::Item &)
@@ -2110,6 +2110,15 @@ bool CalendarView::editIncidence(const Akonadi::Item &item, bool isCounter)
     return true;
 }
 
+void CalendarView::showIncidenceByUid(const QString &uid)
+{
+    const auto item = mCalendar->item(uid);
+    if (item.isValid()) {
+        showIncidenceContext(item);
+        mEventViewer->setIncidence(item);
+    }
+}
+
 void CalendarView::deleteIncidenceFamily(const Akonadi::Item &item)
 {
     const auto incidence = CalendarSupport::incidence(item);
@@ -2502,7 +2511,7 @@ Akonadi::Collection CalendarView::defaultCollection(const QLatin1String &mimeTyp
     }
 
     // 5. Return a invalid collection, the editor will use the first one in the combo
-    return Akonadi::Collection();
+    return {};
 }
 
 IncidenceEditorNG::IncidenceDialog *CalendarView::createIncidenceEditor(const Akonadi::Item &item, const Akonadi::Collection &collection)
