@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef KORG_FILTEREDITDIALOG_H
-#define KORG_FILTEREDITDIALOG_H
+#pragma once
 
 #include "ui_filteredit_base.h"
 
@@ -91,4 +90,3 @@ private:
     Akonadi::TagSelectionDialog *mCategorySelectDialog = nullptr;
 };
 
-#endif
