@@ -3,8 +3,7 @@
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef SUMMARYEVENTTEST_H
-#define SUMMARYEVENTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -19,4 +18,3 @@ private Q_SLOTS:
     void test_eventsForRange();
 };
 
-#endif
