@@ -64,6 +64,7 @@ TodoSummaryWidget::~TodoSummaryWidget() = default;
 
 void TodoSummaryWidget::updateView()
 {
+    // Note: match default entry values with those in KCMTodoSummary::load().
     qDeleteAll(mLabels);
     mLabels.clear();
 
@@ -306,7 +307,6 @@ void TodoSummaryWidget::completeTodo(Akonadi::Item::Id id)
             KCalendarCore::Todo::Ptr oldTodo(todo->clone());
             todo->setCompleted(QDateTime::currentDateTime());
             (void) mChanger->modifyIncidence(todoItem, oldTodo);
-            updateView();
         }
     }
 }
